summaryrefslogtreecommitdiff
path: root/sw/source/filter/ww8/attributeoutputbase.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/source/filter/ww8/attributeoutputbase.hxx')
-rw-r--r--sw/source/filter/ww8/attributeoutputbase.hxx120
1 files changed, 60 insertions, 60 deletions
diff --git a/sw/source/filter/ww8/attributeoutputbase.hxx b/sw/source/filter/ww8/attributeoutputbase.hxx
index a4aabc6a9af1..6d16f55623c0 100644
--- a/sw/source/filter/ww8/attributeoutputbase.hxx
+++ b/sw/source/filter/ww8/attributeoutputbase.hxx
@@ -72,14 +72,14 @@ class SvxCharScaleWidthItem;
class SvxCharReliefItem;
class SvxCharHiddenItem;
class SvxBoxItem;
-class SwFmtINetFmt;
-class SwFmtCharFmt;
-class SwFmtFld;
-class SwFmtFlyCnt;
-class SwFmtFtn;
+class SwFormatINetFormat;
+class SwFormatCharFormat;
+class SwFormatField;
+class SwFormatFlyCnt;
+class SwFormatFootnote;
class SvxLineSpacingItem;
class SvxAdjustItem;
-class SvxFmtSplitItem;
+class SvxFormatSplitItem;
class SvxWidowsItem;
class SvxTabStopItem;
class SvxHyphenZoneItem;
@@ -89,34 +89,34 @@ class SfxPoolItem;
class SfxItemSet;
class SvxParaVertAlignItem;
class SvxParaGridItem;
-class SwFmtFrmSize;
+class SwFormatFrmSize;
class SvxPaperBinItem;
class SvxLRSpaceItem;
class SvxULSpaceItem;
-class SwFmtPageDesc;
-class SvxFmtBreakItem;
-class SwFmtSurround;
-class SwFmtVertOrient;
-class SwFmtHoriOrient;
-class SwFmtAnchor;
+class SwFormatPageDesc;
+class SvxFormatBreakItem;
+class SwFormatSurround;
+class SwFormatVertOrient;
+class SwFormatHoriOrient;
+class SwFormatAnchor;
class SvxBrushItem;
class SvxBoxItem;
-class SwFmtCol;
-class SvxFmtKeepItem;
+class SwFormatCol;
+class SvxFormatKeepItem;
class SwTextGridItem;
-class SwFmtLineNumber;
+class SwFormatLineNumber;
class SvxFrameDirectionItem;
class SfxGrabBagItem;
class SfxUInt16Item;
-class SwFmtRuby;
-class SwTxtNode;
+class SwFormatRuby;
+class SwTextNode;
class SwTOXMark;
class SwRedlineData;
class SwSection;
-class SwFmtDrop;
-class SwFrmFmt;
-class SwNumFmt;
-class SwFmt;
+class SwFormatDrop;
+class SwFrameFormat;
+class SwNumFormat;
+class SwFormat;
struct WW8_SepInfo;
class SwLineNumberInfo;
class SwNumRule;
@@ -156,7 +156,7 @@ public:
virtual void EndParagraph( ww8::WW8TableNodeInfoInner::Pointer_t pTextNodeInfoInner ) = 0;
/// Called in order to output section breaks.
- virtual void SectionBreaks(const SwTxtNode& rNode) = 0;
+ virtual void SectionBreaks(const SwTextNode& rNode) = 0;
/// Called before we start outputting the attributes.
virtual void StartParagraphProperties() = 0;
@@ -195,7 +195,7 @@ public:
virtual void RawText( const OUString& rText, bool bForceUnicode, rtl_TextEncoding eCharSet ) = 0;
/// Output ruby start.
- virtual void StartRuby( const SwTxtNode& rNode, sal_Int32 nPos, const SwFmtRuby& rRuby ) = 0;
+ virtual void StartRuby( const SwTextNode& rNode, sal_Int32 nPos, const SwFormatRuby& rRuby ) = 0;
/// Output ruby end.
virtual void EndRuby() = 0;
@@ -206,7 +206,7 @@ public:
/// Output URL end.
virtual bool EndURL(bool isAtEndOfParagraph) = 0;
- virtual void FieldVanish( const OUString& rTxt, ww::eField eType ) = 0;
+ virtual void FieldVanish( const OUString& rText, ww::eField eType ) = 0;
void StartTOX( const SwSection& rSect );
@@ -214,12 +214,12 @@ public:
virtual void OnTOXEnding() {}
- void TOXMark( const SwTxtNode& rNode, const SwTOXMark& rAttr );
+ void TOXMark( const SwTextNode& rNode, const SwTOXMark& rAttr );
/// Output redlining.
virtual void Redline( const SwRedlineData* pRedline ) = 0;
- virtual void FormatDrop( const SwTxtNode& rNode, const SwFmtDrop& rSwFmtDrop, sal_uInt16 nStyle, ww8::WW8TableNodeInfo::Pointer_t pTextNodeInfo, ww8::WW8TableNodeInfoInner::Pointer_t pTextNodeInfoInner ) = 0;
+ virtual void FormatDrop( const SwTextNode& rNode, const SwFormatDrop& rSwFormatDrop, sal_uInt16 nStyle, ww8::WW8TableNodeInfo::Pointer_t pTextNodeInfo, ww8::WW8TableNodeInfoInner::Pointer_t pTextNodeInfoInner ) = 0;
/// Output FKP (Formatted disK Page) - necessary for binary formats only.
/// FIXME having it in AttributeOutputBase is probably a hack, it
@@ -285,7 +285,7 @@ public:
virtual void EndStyleProperties( bool bParProp ) = 0;
/// Numbering rule and Id.
- virtual void OutlineNumbering( sal_uInt8 nLvl, const SwNumFmt& rNFmt, const SwFmt& rFmt ) = 0;
+ virtual void OutlineNumbering( sal_uInt8 nLvl, const SwNumFormat& rNFormat, const SwFormat& rFormat ) = 0;
/// Page break
/// As a paragraph property - the paragraph should be on the next page.
@@ -322,7 +322,7 @@ public:
virtual void ResetFlyProcessingFlag(){};
/// Description of the page borders.
- virtual void SectionPageBorders( const SwFrmFmt* pFmt, const SwFrmFmt* pFirstPageFmt ) = 0;
+ virtual void SectionPageBorders( const SwFrameFormat* pFormat, const SwFrameFormat* pFirstPageFormat ) = 0;
/// Columns populated from right/numbers on the right side?
virtual void SectionBiDi( bool bBiDi ) = 0;
@@ -363,10 +363,10 @@ public:
protected:
- static void GetNumberPara( OUString& rStr, const SwField& rFld );
+ static void GetNumberPara( OUString& rStr, const SwField& rField );
/// Output frames - the implementation.
- virtual void OutputFlyFrame_Impl( const sw::Frame& rFmt, const Point& rNdTopLeft ) = 0;
+ virtual void OutputFlyFrame_Impl( const sw::Frame& rFormat, const Point& rNdTopLeft ) = 0;
/// Sfx item Sfx item RES_CHRATR_CASEMAP
virtual void CharCaseMap( const SvxCaseMapItem& ) = 0;
@@ -479,25 +479,25 @@ protected:
virtual void CharHighlight( const SvxBrushItem& ) = 0;
/// Sfx item RES_TXTATR_INETFMT
- virtual void TextINetFormat( const SwFmtINetFmt& ) = 0;
+ virtual void TextINetFormat( const SwFormatINetFormat& ) = 0;
/// Sfx item RES_TXTATR_CHARFMT
- virtual void TextCharFormat( const SwFmtCharFmt& ) = 0;
+ virtual void TextCharFormat( const SwFormatCharFormat& ) = 0;
/// Sfx item RES_TXTATR_FIELD, RES_TXTATR_ANNOTATION and RES_TXTATR_INPUTFIELD
- void TextField( const SwFmtFld& );
+ void TextField( const SwFormatField& );
/// Sfx item RES_TXTATR_FLYCNT
- void TextFlyContent( const SwFmtFlyCnt& );
+ void TextFlyContent( const SwFormatFlyCnt& );
/// Sfx item RES_TXTATR_FTN
///
/// This one is common for both WW8AttributeOutput as well as
/// DocxAttributeOutput.
- void TextFootnote( const SwFmtFtn& );
+ void TextFootnote( const SwFormatFootnote& );
/// Sfx item RES_TXTATR_FTN
- virtual void TextFootnote_Impl( const SwFmtFtn& ) = 0;
+ virtual void TextFootnote_Impl( const SwFormatFootnote& ) = 0;
/// Sfx item RES_PARATR_LINESPACING
void ParaLineSpacing( const SvxLineSpacingItem& );
@@ -509,7 +509,7 @@ protected:
virtual void ParaAdjust( const SvxAdjustItem& ) = 0;
/// Sfx item RES_PARATR_SPLIT
- virtual void ParaSplit( const SvxFmtSplitItem& ) = 0;
+ virtual void ParaSplit( const SvxFormatSplitItem& ) = 0;
/// Sfx item RES_PARATR_WIDOWS
virtual void ParaWidows( const SvxWidowsItem& ) = 0;
@@ -524,7 +524,7 @@ protected:
void ParaNumRule( const SwNumRuleItem& );
/// Numbering - the implementation.
- virtual void ParaNumRule_Impl( const SwTxtNode *pTxtNd, sal_Int32 nLvl, sal_Int32 nNumId ) = 0;
+ virtual void ParaNumRule_Impl( const SwTextNode *pTextNd, sal_Int32 nLvl, sal_Int32 nNumId ) = 0;
/// Sfx item RES_PARATR_SCRIPTSPACE
virtual void ParaScriptSpace( const SfxBoolItem& ) = 0;
@@ -542,7 +542,7 @@ protected:
virtual void ParaSnapToGrid( const SvxParaGridItem& ) = 0;
/// Sfx item RES_FRM_SIZE
- virtual void FormatFrameSize( const SwFmtFrmSize& ) = 0;
+ virtual void FormatFrameSize( const SwFormatFrmSize& ) = 0;
/// Sfx item RES_PAPER_BIN
virtual void FormatPaperBin( const SvxPaperBinItem& ) = 0;
@@ -554,22 +554,22 @@ protected:
virtual void FormatULSpace( const SvxULSpaceItem& ) = 0;
/// Sfx item RES_PAGEDESC
- void FormatPageDescription( const SwFmtPageDesc& );
+ void FormatPageDescription( const SwFormatPageDesc& );
/// Sfx item RES_BREAK
- void FormatBreak( const SvxFmtBreakItem& );
+ void FormatBreak( const SvxFormatBreakItem& );
/// Sfx item RES_SURROUND
- virtual void FormatSurround( const SwFmtSurround& ) = 0;
+ virtual void FormatSurround( const SwFormatSurround& ) = 0;
/// Sfx item RES_VERT_ORIENT
- virtual void FormatVertOrientation( const SwFmtVertOrient& ) = 0;
+ virtual void FormatVertOrientation( const SwFormatVertOrient& ) = 0;
/// Sfx item RES_HORI_ORIENT
- virtual void FormatHorizOrientation( const SwFmtHoriOrient& ) = 0;
+ virtual void FormatHorizOrientation( const SwFormatHoriOrient& ) = 0;
/// Sfx item RES_ANCHOR
- virtual void FormatAnchor( const SwFmtAnchor& ) = 0;
+ virtual void FormatAnchor( const SwFormatAnchor& ) = 0;
/// Sfx item RES_BACKGROUND
virtual void FormatBackground( const SvxBrushItem& ) = 0;
@@ -584,12 +584,12 @@ protected:
virtual void FormatBox( const SvxBoxItem& ) = 0;
/// Sfx item RES_COL
- void FormatColumns( const SwFmtCol& );
+ void FormatColumns( const SwFormatCol& );
- virtual void FormatColumns_Impl( sal_uInt16 nCols, const SwFmtCol & rCol, bool bEven, SwTwips nPageSize ) = 0;
+ virtual void FormatColumns_Impl( sal_uInt16 nCols, const SwFormatCol & rCol, bool bEven, SwTwips nPageSize ) = 0;
/// Sfx item RES_KEEP
- virtual void FormatKeep( const SvxFmtKeepItem& ) = 0;
+ virtual void FormatKeep( const SvxFormatKeepItem& ) = 0;
/// Compute the grid character pitch
sal_uInt32 GridCharacterPitch( const SwTextGridItem& rGrid ) const;
@@ -598,7 +598,7 @@ protected:
virtual void FormatTextGrid( const SwTextGridItem& ) = 0;
/// Sfx item RES_LINENUMBER
- virtual void FormatLineNumbering( const SwFmtLineNumber& ) = 0;
+ virtual void FormatLineNumbering( const SwFormatLineNumber& ) = 0;
/// Sfx item RES_FRAMEDIR
virtual void FormatFrameDirection( const SvxFrameDirectionItem& ) = 0;
@@ -613,14 +613,14 @@ protected:
virtual void ParaOutlineLevel( const SfxUInt16Item& ) = 0;
/// Write the expanded field
- virtual void WriteExpand( const SwField* pFld ) = 0;
+ virtual void WriteExpand( const SwField* pField ) = 0;
- virtual void RefField( const SwField& rFld, const OUString& rRef ) = 0;
- virtual void HiddenField( const SwField& rFld ) = 0;
- virtual void SetField( const SwField& rFld, ww::eField eType, const OUString& rCmd ) = 0;
- virtual void PostitField( const SwField* pFld ) = 0;
- virtual bool DropdownField( const SwField* pFld ) = 0;
- virtual bool PlaceholderField( const SwField* pFld ) = 0;
+ virtual void RefField( const SwField& rField, const OUString& rRef ) = 0;
+ virtual void HiddenField( const SwField& rField ) = 0;
+ virtual void SetField( const SwField& rField, ww::eField eType, const OUString& rCmd ) = 0;
+ virtual void PostitField( const SwField* pField ) = 0;
+ virtual bool DropdownField( const SwField* pField ) = 0;
+ virtual bool PlaceholderField( const SwField* pField ) = 0;
virtual bool AnalyzeURL( const OUString& rUrl, const OUString& rTarget, OUString* pLinkURL, OUString* pMark );
@@ -644,7 +644,7 @@ public:
void OutputStyleItemSet( const SfxItemSet& rSet, bool bDeep, bool bTestForDefault );
/// Output frames.
- void OutputFlyFrame( const sw::Frame& rFmt );
+ void OutputFlyFrame( const sw::Frame& rFormat );
void GetTablePageSize
( ww8::WW8TableNodeInfoInner * pTableTextNodeInfoInner,
@@ -653,8 +653,8 @@ public:
/// Exports the definition (image, size) of a single numbering picture bullet.
virtual void BulletDefinition(int /*nId*/, const Graphic& /*rGraphic*/, Size /*aSize*/) {}
- // Returns whether or not the 'SwTxtNode' has a paragraph marker inserted \ deleted (using 'track changes')
- const SwRedlineData* GetParagraphMarkerRedline( const SwTxtNode& rNode, RedlineType_t aRedlineType );
+ // Returns whether or not the 'SwTextNode' has a paragraph marker inserted \ deleted (using 'track changes')
+ const SwRedlineData* GetParagraphMarkerRedline( const SwTextNode& rNode, RedlineType_t aRedlineType );
};
#endif // INCLUDED_SW_SOURCE_FILTER_WW8_ATTRIBUTEOUTPUTBASE_HXX